##
## test_applicants.py
## Login : <uli@pu.smp.net>
## Started on  Tue Aug 24 04:36:11 2010 Uli Fouquet
## $Id$
## 
## Copyright (C) 2010 Uli Fouquet
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Tests for applicants and related.
"""
import logging
import unittest
from StringIO import StringIO
from zope.component.interfaces import IFactory
from zope.interface import verify
from waeup.sirp.interfaces import IWAeUPSIRPPluggable
from waeup.sirp.applicants import (
    ResultEntry, Applicant, ApplicantFactory,
    )
from waeup.sirp.applicants.interfaces import (
    IResultEntry, IApplicant,
    )

class ResultEntryTest(unittest.TestCase):

    def setUp(self):
        self.result_entry = ResultEntry()
        return

    def tearDown(self):
        pass

    def test_interfaces(self):
        verify.verifyClass(IResultEntry, ResultEntry)
        verify.verifyObject(IResultEntry, self.result_entry)

    def test_resultentry(self):
        entry = ResultEntry('Some subject', 3.7)
        assert entry.subject == 'Some subject'
        assert entry.score == 3.7

class ApplicantTest(unittest.TestCase):

    def setUp(self):
        self.applicant = Applicant()

    def tearDown(self):
        pass

    def test_interfaces(self):
        verify.verifyClass(IApplicant, Applicant)
        verify.verifyObject(IApplicant, self.applicant)

class ApplicantFactoryTest(unittest.TestCase):

    def setUp(self):
        self.factory = ApplicantFactory()

    def tearDown(self):
        pass

    def test_interfaces(self):
        verify.verifyClass(IFactory, ApplicantFactory)
        verify.verifyObject(IFactory, self.factory)

    def test_factory(self):
        obj = self.factory()
        assert isinstance(obj, Applicant)

    def test_getInterfaces(self):
        implemented_by = self.factory.getInterfaces()
        assert implemented_by.isOrExtends(IApplicant)

def test_suite():
    suite = unittest.TestSuite()
    for testcase in [
        ResultEntryTest, ApplicantTest, ApplicantFactoryTest,
        ApplicantContainerTest,
        ]:
        suite.addTest(unittest.TestLoader().loadTestsFromTestCase(
                testcase
                )
        )
    return suite
